Tutorials
=========

.. toctree::
   :hidden:

   getting-started/index
   webservice/index
   plug-in/index
   using-templates/index


:doc:`getting-started/index`
    This tutorial will guide you through the steps necessary for installing and
    running the HydraPlatform server


:doc:`webservice/index`
    This tutorial explains basic functionality of the HydraPlatform web service.

:doc:`plug-in/index`
    A tutorial explaining the steps necessary to build your own App.

:doc:`using-templates/index`
    The concepts behind templates are explained by this tutorial.
